@@ -1,10 +1,10 @@
 #ifndef lint
 /*static char yysccsid[] = "from: @(#)yaccpar	1.9 (Berkeley) 02/21/93";*/
 static char yyrcsid[]
-#if __GNUC__ == 2
+#if __GNUC__ >= 2
   __attribute__ ((unused))
-#endif /* __GNUC__ == 2 */
-  = "$OpenBSD: skeleton.c,v 1.19 2002/12/03 21:34:21 mickey Exp $";
+#endif /* __GNUC__ >= 2 */
+  = "$OpenBSD: skeleton.c,v 1.23 2004/03/12 13:39:50 henning Exp $";
 #endif
 #include <stdlib.h>
 #define YYBYACC 1
@@ -23,26 +23,6 @@ static char yyrcsid[]
 #include <am_defs.h>
 #include <amd.h>
 
-/* AIX requires this to be the first thing in the file. */
-#ifndef __GNUC__
-# if HAVE_ALLOCA_H
-#  include <alloca.h>
-# else /* not HAVE_ALLOCA_H */
-#  ifdef _AIX
-/*
- * This pragma directive is indented so that pre-ANSI C compilers will
- * ignore it, rather than choke on it.
- */
- #pragma alloca
-#  else /* not _AIX */
-#   ifndef alloca
-/* predefined by HP cc +Olibcalls */
-voidp alloca();
-#   endif /* not alloca */
-#  endif /* not _AIX */
-# endif /* not HAVE_ALLOCA_H */
-#endif /* not __GNUC__ */
-
 extern char *yytext;
 extern int ayylineno;
 extern int yylex(void);
@@ -63,11 +43,14 @@ static char *header_section = NULL; /* start with no header section */
 # define amu_return(v) return((v))
 #endif /* not PARSE_DEBUG */
 
-#line 93 "../../amd/conf_parse.y"
+#line 73 "../../amd/conf_parse.y"
+#ifndef YYSTYPE_DEFINED
+#define YYSTYPE_DEFINED
 typedef union {
 char *strtype;
 } YYSTYPE;
-#line 71 "conf_parse.c"
+#endif /* YYSTYPE_DEFINED */
+#line 54 "conf_parse.c"
 #define LEFT_BRACKET 257
 #define RIGHT_BRACKET 258
 #define EQUAL 259
@@ -274,7 +257,7 @@ short *yyss;
 short *yysslim;
 YYSTYPE *yyvs;
 int yystacksize;
-#line 169 "../../amd/conf_parse.y"
+#line 149 "../../amd/conf_parse.y"
 
 static int
 yyerror(const char *s)
@@ -285,7 +268,7 @@ yyerror(const char *s)
   exit(1);
   return 1;	/* to full compilers that insist on a return statement */
 }
-#line 237 "conf_parse.c"
+#line 220 "conf_parse.c"
 /* allocate initial stack or double stack size, up to YYMAXDEPTH */
 #if defined(__cplusplus) || defined(__STDC__)
 static int yygrowstack(void)
@@ -479,15 +462,15 @@ yyreduce:
     switch (yyn)
     {
 case 1:
-#line 107 "../../amd/conf_parse.y"
+#line 87 "../../amd/conf_parse.y"
 { yydebug = PARSE_DEBUG; }
 break;
 case 3:
-#line 108 "../../amd/conf_parse.y"
+#line 88 "../../amd/conf_parse.y"
 { yydebug = PARSE_DEBUG; }
 break;
 case 10:
-#line 123 "../../amd/conf_parse.y"
+#line 103 "../../amd/conf_parse.y"
 {
 		  if (yydebug)
 		    fprintf(stderr, "sec_header1 = \"%s\"\n", yyvsp[-2].strtype);
@@ -495,7 +478,7 @@ case 10:
 		}
 break;
 case 13:
-#line 135 "../../amd/conf_parse.y"
+#line 115 "../../amd/conf_parse.y"
 {
 		  if (yydebug)
 		    fprintf(stderr,"parse1: key=\"%s\", val=\"%s\"\n", yyvsp[-3].strtype, yyvsp[-1].strtype);
@@ -507,7 +490,7 @@ case 13:
 		}
 break;
 case 14:
-#line 145 "../../amd/conf_parse.y"
+#line 125 "../../amd/conf_parse.y"
 {
 		  if (yydebug)
 		    fprintf(stderr,"parse2: key=\"%s\", val=\"%s\"\n", yyvsp[-3].strtype, yyvsp[-1].strtype);
@@ -519,7 +502,7 @@ case 14:
 		}
 break;
 case 15:
-#line 155 "../../amd/conf_parse.y"
+#line 135 "../../amd/conf_parse.y"
 {
 		  if (yydebug)
 		    fprintf(stderr,"parse3: key=\"%s\", val=\"%s\"\n", yyvsp[-3].strtype, yyvsp[-1].strtype);
@@ -530,7 +513,7 @@ case 15:
 		  }
 		}
 break;
-#line 482 "conf_parse.c"
+#line 465 "conf_parse.c"
     }
     yyssp -= yym;
     yystate = *yyssp;
@@ -583,7 +566,21 @@ to state %d\n", YYPREFIX, *yyssp, yystate);
 yyoverflow:
     yyerror("yacc stack overflow");
 yyabort:
+    if (yyss)
+            free(yyss);
+    if (yyvs)
+            free(yyvs);
+    yyss = yyssp = NULL;
+    yyvs = yyvsp = NULL;
+    yystacksize = 0;
     return (1);
 yyaccept:
+    if (yyss)
+            free(yyss);
+    if (yyvs)
+            free(yyvs);
+    yyss = yyssp = NULL;
+    yyvs = yyvsp = NULL;
+    yystacksize = 0;
     return (0);
 }
