@@ -1,23 +1,24 @@
 
 #define PACKAGE_NAME "am-utils"
 #define PACKAGE_TARNAME "am-utils"
-#define PACKAGE_VERSION "6.1b3-pre"
-#define PACKAGE_STRING "am-utils 6.1b3-pre"
-#define PACKAGE_BUGREPORT "amd-dev@am-utils.org"
+#define PACKAGE_VERSION "6.1-rc2"
+#define PACKAGE_STRING "am-utils 6.1-rc2"
+#define PACKAGE_BUGREPORT "am-utils@am-utils.org"
 #define HOST_CPU "i386"
 #define HOST_VENDOR "unknown"
-#define HOST_OS "openbsd3.3"
+#define HOST_OS "openbsd3.6"
 #define HOST_OS_NAME "openbsd3"
-#define HOST_OS_VERSION "3.3"
+#define HOST_OS_VERSION "3.6"
 #define HOST_ARCH "i386"
-#define HOST_NAME "a-openbsd33.fsl.cs.sunysb.edu"
+#define DISTRO_NAME "none"
+#define HOST_NAME "a-openbsd36.fsl.cs.sunysb.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Sat Aug  2 14:02:59 EDT 2003"
+#define CONFIG_DATE "Fri Apr 29 10:22:33 EDT 2005"
 #define PACKAGE_NAME "am-utils"
-#define PACKAGE_VERSION "6.1b3-pre"
-#define PACKAGE_BUGREPORT "amd-dev@am-utils.org"
+#define PACKAGE_VERSION "6.1-rc2"
+#define PACKAGE_BUGREPORT "am-utils@am-utils.org"
 #define PACKAGE "am-utils"
-#define VERSION "6.1b3-pre"
+#define VERSION "6.1-rc2"
 #define DEBUG 1
 #define STDC_HEADERS 1
 #define HAVE_SYS_TYPES_H 1
@@ -29,7 +30,7 @@
 #define HAVE_INTTYPES_H 1
 #define HAVE_UNISTD_H 1
 #define HAVE_DLFCN_H 1
-#define HOST_HEADER_VERSION "3.3"
+#define HOST_HEADER_VERSION "3.6"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
 #define HAVE_ALLOCA 1
@@ -57,6 +58,8 @@
 #define HAVE_GETMNTINFO 1
 #define HAVE_GETPAGESIZE 1
 #define HAVE_GETTIMEOFDAY 1
+#define HAVE_HSTRERROR 1
+#define HAVE_MADVISE 1
 #define HAVE_MEMCMP 1
 #define HAVE_MEMCPY 1
 #define HAVE_MEMMOVE 1
@@ -75,12 +78,14 @@
 #define HAVE_SETSID 1
 #define HAVE_SIGACTION 1
 #define HAVE_SIGNAL 1
+#define HAVE_SIGSUSPEND 1
 #define HAVE_SOCKET 1
 #define HAVE_STRCHR 1
-#define HAVE_STRCSPN 1
 #define HAVE_STRCASECMP 1
+#define HAVE_STRCSPN 1
 #define HAVE_STRDUP 1
 #define HAVE_STRERROR 1
+#define HAVE_STRLCPY 1
 #define HAVE_STRSPN 1
 #define HAVE_STRSTR 1
 #define HAVE_SVC_GETREQ 1
@@ -96,6 +101,7 @@
 #define HAVE_STRCASECMP 1
 #define HAVE_STRDUP 1
 #define HAVE_STRERROR 1
+#define HAVE_STRLCPY 1
 #define HAVE_STRSTR 1
 #define HAVE_UALARM 1
 #define HAVE_XDR_ATTRSTAT 1
@@ -143,6 +149,7 @@
 #define HAVE_SYS_WAIT_H 1
 #define HAVE_ARPA_NAMESER_H 1
 #define HAVE_ARPA_INET_H 1
+#define HAVE_LIMITS_H 1
 #define HAVE_MACHINE_ENDIAN_H 1
 #define HAVE_NET_IF_H 1
 #define HAVE_NET_ROUTE_H 1
@@ -194,6 +201,7 @@
 #define HAVE_IFADDRS_H 1
 #define HAVE_GRP_H 1
 #define HAVE_LIBGEN_H 1
+#define HAVE_LIMITS_H 1
 #define HAVE_MALLOC_H 1
 #define HAVE_MEMORY_H 1
 #define HAVE_NDBM_H 1
@@ -219,7 +227,7 @@
 #define nfs_args_t struct nfs_args
 #define NFS_FH_FIELD fh
 #define am_nfs_fh nfs_fh
-#define am_nfs_fh3 nfs_fh3
+#define HAVE_FS_NFS3 1
 #define GETGROUPS_T gid_t
 #define RETSIGTYPE void
 #define HAVE_FHANDLE 1
@@ -249,6 +257,7 @@
 #define HAVE_EXTERN_SETITIMER 1
 #define HAVE_EXTERN_STRCASECMP 1
 #define HAVE_EXTERN_STRDUP 1
+#define HAVE_EXTERN_STRLCPY 1
 #define HAVE_EXTERN_STRSTR 1
 #define HAVE_EXTERN_UALARM 1
 #define HAVE_EXTERN_USLEEP 1
@@ -259,6 +268,7 @@
 #define HAVE_LONG_FILE_NAMES 1
 #define HAVE_UNISTD_H 1
 #define HAVE_RESTARTABLE_SYSCALLS 1
+#define HAVE_FD_SET_FDS_BITS 1
 #define HAVE_STRUCT_STATFS_F_FSTYPENAME 1
 #define HAVE_NFS_ARGS_T_ACDIRMIN 1
 #define HAVE_NFS_ARGS_T_ACREGMIN 1
@@ -270,6 +280,7 @@
 #define HAVE_STRUCT_IFADDRS_IFA_NEXT 1
 #define HAVE_STRUCT_SOCKADDR_SA_LEN 1
 #define HAVE_MAP_FILE 1
+#define HAVE_MAP_EXEC 1
 #define HAVE_MAP_NIS 1
 #define HAVE_MAP_PASSWD 1
 #define HAVE_MAP_UNION 1
@@ -277,7 +288,6 @@
 #define HAVE_FS_LOFS 1
 #define HAVE_FS_MFS 1
 #define HAVE_FS_NFS 1
-#define HAVE_FS_NFS3 1
 #define HAVE_FS_PCFS 1
 #define HAVE_FS_UFS 1
 #define HAVE_FS_NULLFS 1
@@ -287,7 +297,6 @@
 #define HAVE_AMU_FS_DIRECT 1
 #define HAVE_AMU_FS_TOPLVL 1
 #define HAVE_AMU_FS_ERROR 1
-#define HAVE_AMU_FS_INHERIT 1
 #define HAVE_AMU_FS_PROGRAM 1
 #define HAVE_AMU_FS_LINK 1
 #define HAVE_AMU_FS_LINKX 1
@@ -352,5 +361,3 @@
 #define MNT2_CDFS_OPT_NORRIP 0x1
 #define HIDE_MOUNT_TYPE "nfs"
 #define USE_CONNECTED_NFS_SOCKETS 1
-#define HAVE_LIBWRAP 1
-#define NEED_LIBWRAP_SEVERITY_VARIABLES 1
